@@ -117,8 +117,51 @@ impl<'de> Deserialize<'de> for CDuration {
 	}
 }
 
-pub type AsyncHyperResolverConfig = trust_dns_resolver::config::ResolverConfig;
-pub type AsyncHyperResolverOpts = trust_dns_resolver::config::ResolverOpts;
+pub type AsyncTrustDnsResolverConfig = trust_dns_resolver::config::ResolverConfig;
+
+#[derive(Clone, Debug, Deserialize)]
+pub struct AsyncTrustDnsResolverOpts {
+	pub ndots:                  usize,
+	pub timeout:                CDuration,
+	pub attempts:               usize,
+	pub rotate:                 bool,
+	pub check_names:            bool,
+	pub edns0:                  bool,
+	pub validate:               bool,
+	pub ip_strategy:            trust_dns_resolver::config::LookupIpStrategy,
+	pub cache_size:             usize,
+	pub use_hosts_file:         bool,
+	pub positive_min_ttl:       Option<CDuration>,
+	pub negative_min_ttl:       Option<CDuration>,
+	pub positive_max_ttl:       Option<CDuration>,
+	pub negative_max_ttl:       Option<CDuration>,
+	pub num_concurrent_reqs:    usize,
+	pub preserve_intermediates: bool,
+}
+
+#[allow(clippy::from_over_into)]
+impl Into<trust_dns_resolver::config::ResolverOpts> for AsyncTrustDnsResolverOpts {
+	fn into(self) -> trust_dns_resolver::config::ResolverOpts {
+		trust_dns_resolver::config::ResolverOpts {
+			ndots:                  self.ndots,
+			timeout:                *self.timeout,
+			attempts:               self.attempts,
+			rotate:                 self.rotate,
+			check_names:            self.check_names,
+			edns0:                  self.edns0,
+			validate:               self.validate,
+			ip_strategy:            self.ip_strategy,
+			cache_size:             self.cache_size,
+			use_hosts_file:         self.use_hosts_file,
+			positive_min_ttl:       self.positive_min_ttl.map(|v| *v),
+			negative_min_ttl:       self.negative_min_ttl.map(|v| *v),
+			positive_max_ttl:       self.positive_max_ttl.map(|v| *v),
+			negative_max_ttl:       self.negative_max_ttl.map(|v| *v),
+			num_concurrent_reqs:    self.num_concurrent_reqs,
+			preserve_intermediates: self.preserve_intermediates,
+		}
+	}
+}
 
 #[derive(Clone, Debug, Deserialize)]
 pub struct ConcurrencyProfile {
@@ -172,9 +215,9 @@ impl Default for NetworkingProfileValues {
 #[derive(Clone, Debug, Default, Deserialize)]
 pub struct ResolverConfig {
 	#[serde(default)]
-	config:  Option<AsyncHyperResolverConfig>,
+	config:  Option<AsyncTrustDnsResolverConfig>,
 	#[serde(default)]
-	options: Option<AsyncHyperResolverOpts>,
+	options: Option<AsyncTrustDnsResolverOpts>,
 }
 
 #[derive(Clone, Debug, Deserialize)]
@@ -219,7 +262,7 @@ impl ResolvedNetworkingProfile {
 
 		let (config, options) =
 			if let (Some(config), Some(options)) = (p.resolver_config.config, p.resolver_config.options) {
-				(config, options)
+				(config, options.into())
 			} else {
 				trust_dns_resolver::system_conf::read_system_conf()
 					.context("cannot read resolver config settings from system")?
@@ -266,7 +309,7 @@ impl Default for CrawlingSettings {
 			job_hard_timeout:          CDuration::from_secs(60),
 			job_soft_timeout:          CDuration::from_secs(30),
 			load_timeout:              CDuration::from_secs(10),
-			user_agent:                Some(String::from("crusty-core/0.51.0")),
+			user_agent:                Some(String::from("crusty-core/0.52.0")),
 			compression:               true,
 			custom_headers:            HashMap::new(),
 			max_response_size:         CBytes(1024 * 1024 * 2),
